Utils — BCI-Framework documentation

# Utils

This module define usefull decorators to use with data analysis.

`bci_framework.extensions.data_analysis.utils.` `fake_loop_consumer`(*topics) → Callable

  Decorator to iterate methods with new streamming data.

  This decorator will call a method with fake data.

`bci_framework.extensions.data_analysis.utils.` `loop_consumer`(*topics) → Callable

  Decorator to iterate methods with new streamming data.

  This decorator will call a method on every new data streamming input.

`bci_framework.extensions.data_analysis.utils.` `subprocess_this`(fn: Callable) → Callable

  Decorator to move methods to subprocessing.

`bci_framework.extensions.data_analysis.utils.` `thread_this`(fn: Callable) → Callable

  Decorator to move methods to threading.

`bci_framework.extensions.data_analysis.utils.` `timeit`(fn: Callable) → Callable

  Decorator to calculate the execution time of a method.